@@ -38,11 +38,25 @@ class Client():
         )
 
     def get(self,dataset):
-        return(query.query_dataset(client=self._gql_client,name=dataset))
+        query = '''
+            query {
+                dataset(name:"%s"){
+                    name
+                    source
+                    desc
+                    years
+                    results
+                }
+            }
+        '''%dataset
+        query = gql.gql(query)
+        dataset = self._gql_client.execute(query)['dataset']
+        return dataset[0]
 
-c = Client()
-for dataset in c.dataset_names:
-    r = c.get(dataset)
-    print(r['name'],r['years'])
+if __name__ == '__main__':
+    c = Client()
+    for dataset in c.dataset_names:
+        r = c.get(dataset)
+        print(r['name'],r['years'])
 
 
